@@ -4,19 +4,12 @@ use strict;
 
 use Carp();
 
-our $VERSION = '0.765'; # move up to make CPAN happy
-
-require Math::BigInt;
-
-if($Math::BigInt::VERSION >= 1.78)
-{
-  Math::BigInt->import(try => 'GMP');
-}
+use Math::BigInt lib => 'GMP';
 
 use Rose::Object::MakeMethods;
 our @ISA = qw(Rose::Object::MakeMethods);
 
-use Rose::DB::Object::Constants qw(STATE_LOADING MODIFIED_COLUMNS);
+our $VERSION = '0.70';
 
 our $Debug = 0;
 
@@ -31,8 +24,6 @@ sub bigint
   my $min       = $args->{'min'};
   my $max       = $args->{'min'};
 
-  my $column_name = $args->{'column'} ? $args->{'column'}->name : $name;
-
   my $init_method;
 
   if(exists $args->{'with_init'} || exists $args->{'init_method'})
@@ -123,17 +114,7 @@ EOF
   # set code
   #
 
-  my $set_code = qq(\$self->{'$qkey'} = defined \$value ? Math::BigInt->new(\$value) : undef;);
-
-  #
-  # column modified code
-  #
-
-  my $col_name_escaped = $column_name;
-  $col_name_escaped =~ s/'/\\'/g;
-
-  my $column_modified_code = 
-    qq(\$self->{MODIFIED_COLUMNS()}{'$col_name_escaped'} = 1);
+  my $set_code = qq(\$self->{'$qkey'} = Math::BigInt->new(\$value););
 
   #
   # return code
@@ -143,21 +124,18 @@ EOF
 
   if(defined $default)
   {
-    $default = defined $default ? Math::BigInt->new($default) : undef;
+    $default = Math::BigInt->new($default);
 
     $return_code=<<"EOF";
 return (defined \$self->{'$qkey'}) ? \$self->{'$qkey'} : 
-  (scalar($column_modified_code, 
-          \$self->{'$qkey'} = \$default));
+       (\$self->{'$qkey'} = \$default);
 EOF
   }
   elsif(defined $init_method)
   {
     $return_code=<<"EOF";
-return \$self->{'$qkey'}  if(defined \$self->{'$qkey'});
-$column_modified_code;
-my \$init_value = \$self->$init_method();
-return \$self->{'$qkey'} = defined \$init_value ? Math::BigInt->new(\$init_value) : undef;
+return (defined \$self->{'$qkey'}) ? \$self->{'$qkey'} : 
+       (\$self->{'$qkey'} = Math::BigInt->new(\$self->$init_method()));
 EOF
   }
   else
@@ -189,7 +167,6 @@ sub
     $check_in_code
     $min_max_code
     $set_code
-    $column_modified_code  unless(\$self->{STATE_LOADING()});
     $return_code
   }
 
@@ -209,7 +186,6 @@ sub
 
     $check_in_code
     $min_max_code
-    $column_modified_code  unless(\$self->{STATE_LOADING()});
     return $set_code
   }
 
@@ -265,7 +241,6 @@ sub
   $check_in_code
   $min_max_code
   $set_code
-  $column_modified_code  unless(\$self->{STATE_LOADING()});
   $return_code
 };
 EOF
@@ -441,6 +416,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
